timespantools.AnnotatedTimespan
===============================

.. abjad-lineage:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan

.. autoclass:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.annotation
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.axis
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.contains_timespan_improperly
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.curtails_timespan
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.delays_timespan
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.divide_by_ratio
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.duration
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.get_overlap_with_timespan
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.happens_during_timespan
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.intersects_timespan
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_closed
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_congruent_to_timespan
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_half_closed
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_half_open
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_left_closed
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_left_open
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_open
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_right_closed
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_right_open
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_tangent_to_timespan
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_well_formed
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.offsets
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.overlaps_all_of_timespan
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.overlaps_only_start_of_timespan
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.overlaps_only_stop_of_timespan
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.overlaps_start_of_timespan
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.overlaps_stop_of_timespan
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.reflect
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.round_offsets
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.scale
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.set_duration
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.set_offsets
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.split_at_offset
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.split_at_offsets
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.start_offset
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_after_offset
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_after_timespan_starts
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_after_timespan_stops
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_at_offset
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_at_or_after_offset
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_before_offset
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_before_or_at_offset
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_before_timespan_starts
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_before_timespan_stops
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_during_timespan
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_when_timespan_starts
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_when_timespan_stops
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stop_offset
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_after_offset
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_after_timespan_starts
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_after_timespan_stops
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_at_offset
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_at_or_after_offset
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_before_offset
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_before_or_at_offset
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_before_timespan_starts
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_before_timespan_stops
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_during_timespan
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_when_timespan_starts
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_when_timespan_stops
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stretch
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.translate
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.translate_offsets
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.trisects_timespan
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__and__
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__eq__
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__format__
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__ge__
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__gt__
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__hash__
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__le__
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__len__
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__lt__
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__ne__
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__or__
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__repr__
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__sub__
      ~abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__xor__

Bases
-----

- :py:class:`timespantools.Timespan <abjad.tools.timespantools.Timespan.Timespan>`

- :py:class:`mathtools.BoundedObject <abjad.tools.mathtools.BoundedObject.BoundedObject>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.axis
   :noindex:

.. autoattribute:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.duration
   :noindex:

.. autoattribute:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_closed
   :noindex:

.. autoattribute:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_half_closed
   :noindex:

.. autoattribute:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_half_open
   :noindex:

.. autoattribute:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_left_closed
   :noindex:

.. autoattribute:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_left_open
   :noindex:

.. autoattribute:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_open
   :noindex:

.. autoattribute:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_right_closed
   :noindex:

.. autoattribute:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_right_open
   :noindex:

.. autoattribute:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_well_formed
   :noindex:

.. autoattribute:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.offsets
   :noindex:

.. autoattribute:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.start_offset
   :noindex:

.. autoattribute:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stop_offset
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.annotation
   :noindex:

Methods
-------

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.contains_timespan_improperly
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.curtails_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.delays_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.divide_by_ratio
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.get_overlap_with_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.happens_during_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.intersects_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_congruent_to_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.is_tangent_to_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.overlaps_all_of_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.overlaps_only_start_of_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.overlaps_only_stop_of_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.overlaps_start_of_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.overlaps_stop_of_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.reflect
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.round_offsets
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.scale
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.set_duration
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.set_offsets
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.split_at_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.split_at_offsets
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_after_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_after_timespan_starts
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_after_timespan_stops
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_at_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_at_or_after_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_before_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_before_or_at_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_before_timespan_starts
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_before_timespan_stops
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_during_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_when_timespan_starts
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.starts_when_timespan_stops
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_after_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_after_timespan_starts
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_after_timespan_stops
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_at_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_at_or_after_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_before_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_before_or_at_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_before_timespan_starts
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_before_timespan_stops
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_during_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_when_timespan_starts
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stops_when_timespan_stops
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.stretch
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.translate
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.translate_offsets
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.trisects_timespan
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__and__
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__eq__
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__format__
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__ge__
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__gt__
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__hash__
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__le__
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__len__
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__lt__
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__ne__
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__or__
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__repr__
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__sub__
   :noindex:

.. automethod:: abjad.tools.timespantools.AnnotatedTimespan.AnnotatedTimespan.__xor__
   :noindex:
